[Python-checkins] r85130 - python/branches/py3k/Lib/email/message.py

r.david.murray python-checkins at python.org
Fri Oct 1 04:08:02 CEST 2010


Author: r.david.murray
Date: Fri Oct  1 04:08:02 2010
New Revision: 85130

Log:
Fix a couple spelling errors in comments and delete redundant __len__ def.


Modified:
   python/branches/py3k/Lib/email/message.py

Modified: python/branches/py3k/Lib/email/message.py
==============================================================================
--- python/branches/py3k/Lib/email/message.py	(original)
+++ python/branches/py3k/Lib/email/message.py	Fri Oct  1 04:08:02 2010
@@ -98,7 +98,7 @@
     objects, otherwise it is a string.
 
     Message objects implement part of the `mapping' interface, which assumes
     there is exactly one occurrance of the header per message.  Some headers
     do in fact appear multiple times (e.g. Received) and for those headers,
     you must use the explicit API to set or get all the headers.  Not all of
     the mapping methods are implemented.
@@ -290,7 +290,7 @@
         Return None if the header is missing instead of raising an exception.
 
         Note that if the header appeared multiple times, exactly which
-        occurrance gets returned is undefined.  Use get_all() to get all
+        occurrence gets returned is undefined.  Use get_all() to get all
         the values matching a header field name.
         """
         return self.get(name)
@@ -322,9 +322,6 @@
         for field, value in self._headers:
             yield field
 
-    def __len__(self):
-        return len(self._headers)
-
     def keys(self):
         """Return a list of all the message's header field names.
 
@@ -98,7 +98,7 @@
 
     Message objects implement part of the `mapping' interface, which assumes
-    there is exactly one occurrance of the header per message.  Some headers
+    there is exactly one occurrence of the header per message.  Some headers
     do in fact appear multiple times (e.g. Received) and for those headers,
     you must use the explicit API to set or get all the headers.  Not all of


More information about the Python-checkins mailing list